==> exo.jcr.applications.openofficeplugin-1.10.4-sources.jar: org/exoplatform/applications/ooplugin/OOConstants.java <==
/*
 * Copyright (C) 2003-2008 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.applications.ooplugin;

/**
 * Created by The eXo Platform SAS
 * Author : Dmytro Katayev
 *          work.visor.ck@gmail.com
 * Aug 28, 2008  
 */
public class OOConstants {
  
  public static class MimeTypes{
    
    
    // OpenDocument Text
    public static final String ODT = "application/vnd.oasis.opendocument.text";    
    // OpenDocument Presentation 
    public static final String ODP = "application/vnd.oasis.opendocument.presentation";
    // OpenDocument Spreadsheet
    public static final String ODS = "application/vnd.oasis.opendocument.spreadsheet";   
    //Microsoft Rich Text Format
    public static final String RTF = "application/vnd.oasis.opendocument.spreadsheet";
    // MS word document
    public static final String DOC = "application/msword";
    // MS PowerPoint
    public static final String PPT = "application/vnd.ms-powerpoint ";
    // Spreadsheet
    public static final String XLS = "application/msexcel";            
 
  } 

}

==> exo.jcr.applications.openofficeplugin-1.10.6-sources.jar: org/exoplatform/applications/ooplugin/OOConstants.java <==
/*
 * Copyright (C) 2003-2008 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.applications.ooplugin;

/**
 * Created by The eXo Platform SAS Author : Dmytro Katayev work.visor.ck@gmail.com Aug 28, 2008
 */
public class OOConstants {

  public static class MimeTypes {

    // OpenDocument Text
    public static final String ODT = "application/vnd.oasis.opendocument.text";

    // OpenDocument Presentation
    public static final String ODP = "application/vnd.oasis.opendocument.presentation";

    // OpenDocument Spreadsheet
    public static final String ODS = "application/vnd.oasis.opendocument.spreadsheet";

    // Microsoft Rich Text Format
    public static final String RTF = "application/vnd.oasis.opendocument.spreadsheet";

    // MS word document
    public static final String DOC = "application/msword";

    // MS PowerPoint
    public static final String PPT = "application/vnd.ms-powerpoint ";

    // Spreadsheet
    public static final String XLS = "application/msexcel";

  }

}
